summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/kxt/app.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/kxt/app.cpp')
-rw-r--r--languages/cpp/app_templates/kxt/app.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/languages/cpp/app_templates/kxt/app.cpp b/languages/cpp/app_templates/kxt/app.cpp
index 6f3e19fb..183841ad 100644
--- a/languages/cpp/app_templates/kxt/app.cpp
+++ b/languages/cpp/app_templates/kxt/app.cpp
@@ -25,14 +25,14 @@
#include <kstdaction.h>
%{APPNAMELC}::%{APPNAMELC}()
- : KMainWindow( 0, "%{APPNAMELC}" ),
+ : TDEMainWindow( 0, "%{APPNAMELC}" ),
m_view(new %{APPNAMELC}View(this)),
m_printer(0)
{
// accept dnd
setAcceptDrops(true);
// tell the KMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions
@@ -71,7 +71,7 @@ void %{APPNAMELC}::setupActions()
KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
// custom menu and menu item - the slot is in the class %{APPNAMELC}View
- KAction *custom = new KAction(i18n("Swi&tch Colors"), 0,
+ TDEAction *custom = new TDEAction(i18n("Swi&tch Colors"), 0,
m_view, TQT_SLOT(switchColors()),
actionCollection(), "switch_action");
@@ -25,14 +25,14 @@
// accept dnd
setAcceptDrops(true);
- // tell the KMainWindow that this is indeed the main widget
+ // tell the TDEMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions